@@ -39,7 +39,8 @@ bool from_string( const string & Str, T & Dest )
   // crer un flux  partir de la chaine donne
   istringstream iss( Str );
   // tenter la conversion vers Dest
-  return iss >> Dest != 0;
+  iss >> Dest;
+  return !Dest;
 };
 
 
