@@ -417,6 +417,11 @@ Mesh * GMSH_Load(const string & filename)
     fclose(fp);
 
     Mesh *pTh = new Mesh(nv,nt,nbe,vff,tff,bff);
+    R2 Pn,Px;
+    pTh->BoundingBox(Pn,Px);
+    if(!pTh->quadtree)
+        pTh->quadtree=new Fem2D::FQuadTree(pTh,Pn,Px,pTh->nv);
+
     return pTh;
 
   }
@@ -820,7 +825,7 @@ class Init1 { public:
   Init1();
 };
 
-static Init1 init1;  //  une variable globale qui serat construite  au chargement dynamique 
+LOADINIT(Init1)  //  une variable globale qui serat construite  au chargement dynamique 
 
 Init1::Init1(){  // le constructeur qui ajoute la fonction "splitmesh3"  a freefem++ 
   
