@@ -7,7 +7,7 @@
 // AUTHOR   : Jacques Morice
 // E-MAIL   : jacques.morice@ann.jussieu.fr
 //
-//ff-c++-LIBRARY-dep:  mumps parmetis ptscotch  scalapack blacs blas  mpifc  fc  pthread 
+//ff-c++-LIBRARY-dep: mumps parmetis ptscotch scalapack blas mpifc fc mpi pthread 
 //ff-c++-cpp-dep: 
 
 /* 
@@ -36,6 +36,18 @@
 #include  <iostream>
 using namespace std;
 
+#ifdef WIN32
+
+// ALH - this activates the Windows DLL default export mechanism
+
+__declspec(dllexport) int not_used;
+
+// FFCS - 23/4/13 - instanciate some global symbols which are not found by default in MS MPI Fortran libraries
+
+MPI_Fint* _imp__MPI_F_STATUS_IGNORE;
+MPI_Fint* _imp__MPI_F_STATUSES_IGNORE;
+#endif
+
 #include "rgraph.hpp"
 #include "error.hpp"
 #include "AFunction.hpp"
@@ -310,11 +322,11 @@ public:
     id.comm_fortran= (MUMPS_INT) MPI_Comm_c2f( comm );
     //id.comm_fortran= (F_INT) comm;
 
-    if(verbosity) cout << "init parameter :: PAR & SYM " << PAR << " " << SYM << endl; 
+    if(verbosity>2) cout << " MUMPS_FreeFem init parameter :: PAR & SYM " << PAR << " " << SYM << endl; 
 
     dmumps_c(&id);
 
-    if(verbosity) cout << "fin init parameter" << endl; 
+    if(verbosity>10) cout << "fin init parameter" << endl; 
 
     /* set parameter of mumps */
     if( !(param_int == NULL) || !(param_double == NULL) ){
@@ -348,6 +360,7 @@ public:
       }
       else{
 	// parameter by default
+	if(verbosity>10) 
 	cout << "default parameter" << endl;
 	id.ICNTL(1)=-1; id.ICNTL(2)=-1; id.ICNTL(3)=-1; id.ICNTL(4)=0;
     }
@@ -1317,7 +1330,7 @@ public:
   }
 
   ~dSolveMUMPSmpi() { 
-    if(verbosity)
+    if(verbosity>10)
       cout << "~SolveMUMPS S:" << endl;
     
      id.job=JOB_END; 
