@@ -4,6 +4,14 @@
 #else
 #include <unistd.h>
 #endif
+
+// FFCS: required for chdir() when g++ 4.7 is used
+#include <unistd.h>
+
+// FFCS: redirecting visualization output
+#include "../fflib/ffapi.hpp"
+#include <string>
+
 extern long mpirank;
 extern long verbosity;
 extern FILE *ThePlotStream; //  Add for new plot. FH oct 2008
@@ -11,6 +19,7 @@ extern FILE *ThePlotStream; //  Add for new plot. FH oct 2008
 extern const char *  prognamearg;
 extern const char *  edpfilenamearg;
 extern bool  waitatend;
+extern bool  consoleatend;
 extern bool echo_edp;
 extern bool 	  NoGraphicWindow;
 
@@ -52,6 +61,7 @@ char * Shell_Space(const char * s)
 int getprog(char* fn,int argc, char **argv)
 {
   waitatend=true;  // attent 
+  consoleatend=false;  // bug with redirection FH 
   int ret=0;
   *fn='\0';
 #ifdef WIN32
@@ -68,19 +78,13 @@ int getprog(char* fn,int argc, char **argv)
   const char *progffglut=0;
   const char *fileglut=0;
   bool noffglut=false;
-#ifndef NODEFFFGLUT
-  if(argc)
-    {
-      const char *prog =argv[0];
-      const char *pm= strrchr(argv[0],'-');      
-      if( pm )
-        noffglut = ((strlen(prog)- (pm-prog)) < lsuffix+5);
-      else   noffglut==  false;
-      //      cout << " noffglut= " << noffglut << endl;
-      //  suffix ++-glx.exe -> no ffglut
-      // pm = 0= > pas de moins -> freefem++ -> ffglut
-    }
-#endif
+
+  // FFCS - remove the test for noffglut to be able to create pictures
+  // in any situation. Even FreeFem++-mpilang needs to send pictures
+  // (eg when called in a FreeFem++-server situation by EJS)
+
+  noffglut=false;
+
   bool ch2edpdir = false;
   if(argc)
     prognamearg=argv[0];
@@ -102,6 +106,7 @@ int getprog(char* fn,int argc, char **argv)
 	}
       else if  (strcmp(argv[i],"-nw")==0 ) 
 	{
+	  consoleatend=false;
 	  noffglut=true;
 	  NoGraphicWindow=true; 
 	}
@@ -114,6 +119,10 @@ int getprog(char* fn,int argc, char **argv)
 	  echo_edp=false;
       else if  (strcmp(argv[i],"-nowait")==0 ) 
 	waitatend=false;
+      else if  (strcmp(argv[i],"-nc")==0 ) 
+	consoleatend=false;
+      else if  (strcmp(argv[i],"-log")==0 ) 
+	consoleatend=true;
       else if  (strcmp(argv[i],"-wait")==0 ) 
 	  waitatend=true;
       else if(strcmp(argv[i],"-fglut")==0 && i+1 < argc)
@@ -167,11 +176,9 @@ if( ch2edpdir && edpfilenamearg)
 	int err=0;
 	if(verbosity>1) 
 	    cout << " chdir '" << dir <<"'"<< endl;
-#if WIN32	
-	err=_chdir(dir);
-#else
+	// FFCS: mingw64 API change
 	err=chdir(dir);
-#endif
+
 	//cout << err << endl;
          if(err) {
 	     cerr << " error : chdir  " << dir << endl;
@@ -188,9 +195,15 @@ if( ch2edpdir && edpfilenamearg)
   
   if(progffglut && mpirank==0)
     {
-      ThePlotStream = popen(progffglut,"w");		   
-      if(verbosity)
-	printf(" EXEC of the plot  : %s\n",progffglut);
+      // FFCS: divert stream to FFCS
+      ThePlotStream = ffapi::ff_popen(progffglut,"w");		   
+
+      // FFCS: just forget the following message because it could be understood as an error during FFCS execution
+      // although ffglut is not used there.
+
+      //if(verbosity)
+      //  printf(" EXEC of the plot  : %s\n",progffglut);
+
       if(!ThePlotStream) { cerr << "  Error popen  "<< progffglut << endl;exit(1);}
       
     }
