@@ -1,4 +1,4 @@
-//#define NCHECKPTR // BUg with MPI ??? FH 
+#define NCHECKPTR // BUg with MPI ??? FH 
 #ifndef NCHECKPTR
 #define DEBUGUNALLOC 1 
 // -*- Mode : c++ -*-
@@ -302,7 +302,7 @@ void AllocExtern::init()
    static int count=0;
    if(0== (count++)) 
     {
-      sprintf(filename,"ListOf>llocPtr-%d.bin",(int) sizeof(void*));
+      sprintf(filename,"ListOfAllocPtr-%d.bin",(int) sizeof(void*));
       AllocSize =0;
       MaxUsedSize =0;
       AllocHead =0;  
@@ -434,26 +434,26 @@ int ShowAlloc(const char *s,size_t & lg)
 #include <new>
 
 long  CheckPtr___nbptr=0; 
-void* operator new( size_t size ) {
+void* operator new( size_t size ) throw(std::bad_alloc) {
     CheckPtr___nbptr++;
     void *p = malloc( size );
     
     return p;
 }
 
-void* operator new[]( size_t size ) {  
+void* operator new[]( size_t size ) throw(std::bad_alloc) {  
     void *p = malloc(size);
      CheckPtr___nbptr++;
     return p;
 }
 
-void operator delete( void *p ) {  
+void operator delete( void *p ) throw() {  
     free(p);
     CheckPtr___nbptr--;
 
 }
 
-void operator delete[]( void *p ) {
+void operator delete[]( void *p ) throw() {
     free(p);
     CheckPtr___nbptr--;
 
