@@ -655,6 +655,7 @@ template<class K>
 template<class R,class M,class P> 
 int ConjuguedGradient(const M & A,const P & C,const KN_<R> &b,KN_<R> &x,const int nbitermax, double &eps,long kprint=1000000000)
 {
+   
 //  ConjuguedGradient lineare   A*x est appele avec des conditions au limites 
 //  non-homogene puis homogene  pour calculer le gradient  
    if (verbosity>50) 
@@ -666,12 +667,12 @@ int ConjuguedGradient(const M & A,const P & C,const KN_<R> &b,KN_<R> &x,const in
    throwassert(n==x.N());
    Rn g(n), h(n), Ah(n), & Cg(Ah);  // on utilise Ah pour stocke Cg  
    g = A*x;  
-   double xx= real((x,conj(x)));
+   double xx= RNM::real((x,conj(x)));
    double epsold=eps;
    g -= b;// g = Ax-b
    Cg = C*g; // gradient preconditionne 
    h =-Cg; 
-   double g2 = real((Cg,conj(g)));
+   double g2 = RNM::real((Cg,conj(g)));
    if (g2 < 1e-30) 
     { if(verbosity>1)
        cout << "GC  g^2 =" << g2 << " < 1.e-30  Nothing to do " << endl;
@@ -681,14 +682,14 @@ int ConjuguedGradient(const M & A,const P & C,const KN_<R> &b,KN_<R> &x,const in
    for (int iter=0;iter<=nbitermax;iter++)
      {      
        Ah = A*h;
-       double hAh =real((h,conj(Ah)));
+       double hAh =RNM::real((h,conj(Ah)));
       // if (Abs(hAh)<1e-30) ExecError("CG2: Matrix non defined, sorry ");
-       R ro =  - real((g,conj(h)))/ hAh; // ro optimal (produit scalaire usuel)
+       R ro =  - RNM::real((g,conj(h)))/ hAh; // ro optimal (produit scalaire usuel)
        x += ro *h;
        g += ro *Ah; // plus besoin de Ah, on utilise avec Cg optimisation
        Cg = C*g;
        double g2p=g2; 
-       g2 = real((Cg,conj(g)));
+       g2 = RNM::real((Cg,conj(g)));
        if ( !(iter%kprint) && iter && (verbosity>3) )
          cout << "CG:" <<iter <<  "  ro = " << ro << " ||g||^2 = " << g2 << endl; 
        if (g2 < reps2) { 
@@ -752,7 +753,7 @@ int ConjuguedGradient2(const M & A,const P & C,KN_<R> &x,const KN_<R> &b,const i
        Ah -= b;        //   Ax + rop*Ah = rop*Ah + g  =
        Ah -= g;         //   Ah*rop  
        R hAh =(h,Ah);
-       if (norm(hAh)<1e-60) ExecError("CG2: Matrix is not defined (/0), sorry ");
+         if (RNM::norm2(hAh)<1e-60) ExecError("CG2: Matrix is not defined (/0), sorry ");
        ro =  - (g,h)*rop/hAh ; // ro optimal (produit scalaire usuel)
        x += (ro-rop) *h;
        g += (ro/rop) *Ah; // plus besoin de Ah, on utilise avec Cg optimisation
@@ -822,13 +823,13 @@ plusAx operator*(const KN_<R> &  x) const {return plusAx(this,x);}
 };
 
 struct TypeSolveMat {
-    enum TSolveMat { NONESQUARE=0, LU=1, CROUT=2, CHOLESKY=3, GC = 4 , GMRES = 5, SparseSolver=6 };
+    enum TSolveMat { NONESQUARE=0, LU=1, CROUT=2, CHOLESKY=3, GC = 4 , GMRES = 5, SparseSolver=6, SparseSolverSym=7 };
     TSolveMat t;
     bool sym;
     bool profile;
     TypeSolveMat(TSolveMat tt=LU) :t(tt),
-    sym(t == CROUT || t ==CHOLESKY  ||  t==GC ),
-    profile(t != GC && t != GMRES && t != NONESQUARE && t != SparseSolver ) {}
+    sym(t == CROUT || t ==CHOLESKY  ||  t==GC || t==SparseSolverSym ),
+    profile(t == CROUT || t ==CHOLESKY  || t ==LU ) {}
     bool operator==(const TypeSolveMat & a) const { return t == a.t;}                               
     bool operator!=(const TypeSolveMat & a) const { return t != a.t;}
     static TSolveMat defaultvalue;
@@ -837,8 +838,10 @@ struct TypeSolveMat {
 // add FH , JM  avril 2009 
 template<class K,class V> class MyMap;
 class String; 
-typedef void *    pcommworld; // to get the pointeur to the comm word ... in mpi 
-
+typedef void *    pcommworld; // to get the pointeur to the comm word ... in mpi
+//  to build 
+#define VDATASPARSESOLVER  1
+int Data_Sparse_Solver_version() ; //{ return VDATASPARSESOLVER;}
 struct Data_Sparse_Solver {
   bool initmat;
   TypeSolveMat* typemat;
@@ -863,6 +866,7 @@ struct Data_Sparse_Solver {
   KN<double> scale_c; 
   string sparams;  
   pcommworld commworld;  // pointeur sur le commworld
+    int master; //  master rank in comm add FH 02/2013 for MUMPS ... => VDATASPARSESOLVER exist 
  /*   
   int *param_int;
   double *param_double;
@@ -909,8 +913,10 @@ struct Data_Sparse_Solver {
     file_param_perm_c(0),
      */
     //sparams, 
-    commworld(0)
+    commworld(0),
+    master(0)
     {}
+    
 private:
     Data_Sparse_Solver(const Data_Sparse_Solver& ); // pas de copie 
 };
@@ -945,6 +951,25 @@ template<class R> struct DefSparseSolver {
   }
 };
 
+// add Dec 2012 F.H. for optimisation .. 
+template<class R> struct DefSparseSolverSym {
+    typedef typename MatriceMorse<R>::VirtualSolver *
+    (*SparseMatSolver)(DCL_ARG_SPARSE_SOLVER(R,A) );
+    
+    static SparseMatSolver solver;
+    
+    static  typename MatriceMorse<R>::VirtualSolver *
+    
+    Build( DCL_ARG_SPARSE_SOLVER(R,A) )
+    
+    {
+        typename MatriceMorse<R>::VirtualSolver *ret=0;
+        if(solver)
+            ret =(solver)(ARG_SPARSE_SOLVER(A));
+        return ret;	
+    }
+};
+
 // End Sep 2007 for generic Space solver
 
 
