@@ -13,7 +13,11 @@
 //  cblas_ddot macos-9 is not 
 #ifdef HAVE_CBLAS_H
 extern "C" {
-#include <cblas.h> 
+#define FF_VERSION VERSION
+#undef VERSION
+#include <cblas.h>
+#undef VERSION   
+#define VERSION VERSION    
 }
 #define WITHBLAS 1
 #elif HAVE_VECLIB_CBLAS_H
@@ -34,26 +38,48 @@ template<class R> inline R blas_sdot(const int n,const R *sx,const int incx,cons
     s += *sx * *sy;   
    return  s;
 }
-template<> inline float blas_sdot(const int n,const  float *sx,const int incx,const float *sy,const int  incy)
+
+template<class R> inline R blas_sdot( int n, R *sx, int incx, R *sy, int  incy)
 {
-  return cblas_sdot(n,sx,incx,sy,incy);
+    R s=R();
+    
+    if(incx == 1 && incy == 1)
+        for (int k = 0; k< n; k++)
+            s += *sx++ * * sy++;
+    else
+        for (int k = 0; k< n; k++, sx += incx, sy += incy)
+            s += *sx * *sy;
+    return  s;
 }
-template<> inline double blas_sdot(const int n,const  double *sx,const int incx,const double *sy,const int  incy)
+// OpenBlas PB with constant  remove const ....
+template<> inline float blas_sdot(const int n,  float *sx, int incx, float *sy, int  incy)
 {
-  return cblas_ddot(n,sx,incx,sy,incy);
+    return cblas_sdot(n,sx,incx,sy,incy);
 }
-template<> inline  complex<double> blas_sdot(const int n,const  complex<double> *sx,const int incx,const complex<double> *sy,const int  incy)
+template<> inline double blas_sdot( int n,  double *sx, int incx, double *sy, int  incy)
 {
-  complex<double> s;
-   cblas_zdotu_sub(n,(const void *)sx,incx,(const void *)sy,incy,( void *)&s);
-  return s;
+    return cblas_ddot(n,sx,incx,sy,incy);
 }
-template<> inline  complex<float> blas_sdot(const int n,const  complex<float> *sx,const int incx,const complex<float> *sy,const int  incy)
+
+#ifdef OPENBLAS_CONFIG_H
+typedef  openblas_complex_double *BLAS_ptr_complex16;
+#else
+typedef void *BLAS_ptr_complex16;
+
+#endif
+template<> inline  complex<double> blas_sdot( int n,  complex<double> *sx, int incx, complex<double> *sy, int  incy)
 {
-  complex<float> s;
-   cblas_zdotu_sub(n,(const void *)sx,incx,(const void *)sy,incy,( void *)&s);
-  return s;
+    complex<double> s;
+    cblas_zdotu_sub(n,( double *)sx,incx,( double *)sy,incy,(BLAS_ptr_complex16)&s);
+    return s;
 }
+//template<> inline  complex<float> blas_sdot( int n,  complex<float> *sx, int incx, complex<float> *sy, int  incy)
+//{
+//    complex<float> s;
+//    cblas_cdotu_sub(n,( void *)sx,incx,( void *)sy,incy,(BLAS_ptr_complex8)&s);
+//    return s;
+//}
+
 #endif
 //  end modif FH
 using Fem2D::HeapSort;
@@ -273,28 +299,39 @@ template<class R>
 template<class R>
 bool MatriceProfile<R>::addMatTo(R coef,std::map< pair<int,int>, R> &mij,bool trans,int ii00,int jj00,bool cnj,double threshold)
 {
-   double eps0=max(numeric_limits<double>::min(), threshold);
- if( norm(coef)<eps0) return  L == U ;
- int i,j,kf,k;
-  if(D)
-   for( i=0;i<this->n;i++)
-    if( norm(D[i])>eps0)
-     mij[ij_mat(trans,ii00,jj00,i,i)] += coef*(cnj? conj(D[i]) : D[i]);
-   else
-   for(int i=0;i<this->n;i++) // no dia => identity dai
-     mij[ij_mat(trans,ii00,jj00,i,i)] += coef;
-     
- if (L && pL )    
-   for (kf=pL[0],i=0;  i<this->n;   i++  )  
-     for ( k=kf,kf=pL[i+1], j=i-kf+k;   k<kf; j++,  k++  )
-        if(norm(L[k])>eps0)
-        mij[ij_mat(trans,ii00,jj00,i,j)]= coef*(cnj? conj(L[k]) : L[k]);
- if (U && pU)     
-   for (kf=pU[0],j=0;  j<this->m;  j++)  
-     for (k=kf,kf=pU[j+1], i=j-kf+k;   k<kf; i++,  k++  )
-      if(norm(U[k])>eps0)
-        mij[ij_mat(trans,ii00,jj00,i,j)]= coef*(cnj? conj(U[k]) : U[k]);
- return L == U ; // symetrique               
+    double eps0=max(numeric_limits<double>::min(), threshold);
+    if( RNM::norm2(coef)<eps0) return  L == U ;
+    int i,j,kf,k;
+    if(D)
+    {
+        for( i=0;i<this->n;i++)
+            if( RNM::norm2(D[i])>eps0)
+                mij[ij_mat(trans,ii00,jj00,i,i)] += coef*(cnj? RNM::conj(D[i]) : D[i]);
+    }
+    else
+    {
+        for(int i=0;i<this->n;i++) // no dia => identity dai
+            mij[ij_mat(trans,ii00,jj00,i,i)] += coef;
+    }
+    if (L && pL )
+        for (kf=pL[0],i=0;  i<this->n;   i++  )
+	  { 
+	    k=kf;
+	    kf=pL[i+1];
+	    for ( j=i-kf+k;   k<kf; j++,  k++  )
+                if(RNM::norm2(L[k])>eps0)
+		  mij[ij_mat(trans,ii00,jj00,i,j)]= coef*(cnj? RNM::conj(L[k]) : L[k]);
+	  }
+    if (U && pU)
+        for (kf=pU[0],j=0;  j<this->m;  j++)
+	  {
+	    k=kf;
+	    kf=pU[j+1];
+	    for ( i=j-kf+k;   k<kf; i++,  k++  )
+	      if(RNM::norm2(U[k])>eps0)
+		mij[ij_mat(trans,ii00,jj00,i,j)]= coef*(cnj? RNM::conj(U[k]) : U[k]);
+	  }
+    return L == U ; // symetrique
 }
 template<class R>
 MatriceProfile<R>::MatriceProfile(const int nn,const R *a)
@@ -353,7 +390,8 @@ MatriceProfile<R>::MatriceProfile(const FESpace & Vh,bool VF)
 	    mn = Min ( mn , Vh.FirstDFOfNode(j) ) ;}
         }
        //for( k=tabk[ie=0]; ie <itab; k=tabk[++ie])
-        { k=ke; // bof bof a verifier finement .... FH
+        { 
+	  k=ke; // bof bof a verifier finement .... FH
 	  iVhk=(int) Vh(k);  
         //for (j=Vh(k,jl=0);jl<(int) Vh(k);j=Vh(k,++jl)) 
 	for (jl=0;jl<iVhk;jl++) // modif Oct 2008 valgrind
@@ -393,15 +431,23 @@ void MatriceProfile<R>::addMatMul(const KN_<R> &x,KN_<R> &ax) const
       
  if (L && pL )    
    for (kf=pL[0],i=0;  i<this->n;   i++  )  
-     for ( k=kf,kf=pL[i+1], j=i-kf+k;   k<kf; j++,  k++  )
-       ax[i] += L[k]*x[j],throwassert(i>=0 && i <this->n && j >=0 && j < this->m && k>=0 && k < pL[this->n]);
-       
+     { 
+       k=kf;
+       kf=pL[i+1];
+       for ( j=i-kf+k;   k<kf; j++,  k++  )
+	 ax[i] += L[k]*x[j],throwassert(i>=0 && i <this->n && j >=0 && j < this->m && k>=0 && k < pL[this->n]);
+     }
+ 
  if (U && pU)     
    for (kf=pU[0],j=0;  j<this->m;  j++)  
-     for (k=kf,kf=pU[j+1], i=j-kf+k;   k<kf; i++,  k++  )
-       ax[i] += U[k]*x[j],throwassert(i>=0 && i <this->n && j >=0 && j < this->m &&  k>=0 && k < pU[this->n]);
+     {
+       k=kf;
+       kf=pU[j+1];
+       for ( i=j-kf+k;   k<kf; i++,  k++  )
+	 ax[i] += U[k]*x[j],throwassert(i>=0 && i <this->n && j >=0 && j < this->m &&  k>=0 && k < pU[this->n]);
+     }
+ 
  
-
 }
 
 
@@ -530,7 +576,7 @@ void MatriceProfile<R>::cholesky(double eps) const {
   if (L != U) ERREUR(factorise,"Skyline matrix non symmetric");
   U = 0; // 
   typefac = FactorizationCholeski;
-  if ( norm(D[0]) <= 1.0e-60)
+  if ( RNM::norm2(D[0]) <= 1.0e-60)
       ERREUR(cholesky,"pivot (" << 0 << ")= " << D[0] )
   
   D[0] = sqrt(D[0]); 
@@ -553,8 +599,8 @@ void MatriceProfile<R>::cholesky(double eps) const {
       *ij =  -s/D[j] ;
       xii -= *ij * *ij ;
       }
-    // cout << norm(xii) << " " << Max(eps2*norm(D[i]),1.0e-60) << " " << sqrt(xii) <<endl;
-    if ( norm(xii) <= Max(eps2*norm(D[i]),1.0e-60)) 
+    // cout << RNM::norm2(xii) << " " << Max(eps2*RNM::norm2(D[i]),1.0e-60) << " " << sqrt(xii) <<endl;
+    if ( RNM::norm2(xii) <= Max(eps2*RNM::norm2(D[i]),1.0e-60)) 
       ERREUR(cholesky,"pivot (" << i << ")= " << xii << " < " << eps*abs(D[i]))
     D[i] = sqrt(xii);
     }
@@ -585,7 +631,7 @@ void MatriceProfile<R>::crout(double eps) const  {
 
       xii -= *ij * *ij * *dkk;
       }
-    if (norm(xii) <= Max(eps2*norm(D[i]),1.0e-60))
+    if (RNM::norm2(xii) <= Max(eps2*RNM::norm2(D[i]),1.0e-60))
       ERREUR(crout,"pivot (" << i << " )= " << abs(xii)<< " <= " << eps*abs(D[i]) << " eps = " << eps)
 	D[i] = xii;
     }
@@ -651,7 +697,7 @@ void MatriceProfile<R>::LU(double eps) const  {
       // cout << " k0 " << k0 << " i = " << i << " " <<  s << endl;
       uii = D[i] -s;
       
-      if (norm(uii) <= Max(eps2*norm(D[i]),1.0e-30))
+      if (RNM::norm2(uii) <= Max(eps2*RNM::norm2(D[i]),1.0e-30))
 	ERREUR(LU,"pivot (" << i << " )= " << abs(uii) << " <= " << eps*abs(D[i]) << " eps = " << eps);     
       
       D[i] = uii;
@@ -745,7 +791,7 @@ template <class R>
   int nbcoeff=0;
   for(int i=0;i<this->n;i++)
     for(int j=0;j<this->m;j++)
-      if(norm(A(i,j))>tol2) nbcoeff++;
+      if(RNM::norm2(A(i,j))>tol2) nbcoeff++;
 
   nbcoef=nbcoeff;
   nbcoeff=Max(nbcoeff,1); // pour toujours alloue quelque chose FH Bug dans CheckPtr
@@ -759,7 +805,7 @@ template <class R>
     lg[i]=nbcoeff;
     for(int j=0;j<this->m;j++)
      
-      if(norm(aij=A(i,j))>tol2)
+      if(RNM::norm2(aij=A(i,j))>tol2)
        {
          cl[nbcoeff]=j;
          a[nbcoeff]=aij;
@@ -941,7 +987,7 @@ ostream& MatriceMorse<R>::dump(ostream & f) const
     int ke=lg[i+1];
     for (;k<ke;k++)
       f << setw(9) << i+1 << ' ' << setw(9) << cl[k]+1 << ' ' << setprecision( 20) << a[k]<< '\n' ;
-     // if (norm(a[k])) f  << cl[k] << " " << a[k]<< ", ";
+     // if (RNM::norm2(a[k])) f  << cl[k] << " " << a[k]<< ", ";
      // else f  << cl[k] << " 0., " ;
    // f << endl;    
    }
@@ -1105,7 +1151,7 @@ void MatriceMorse<R>::Build(const FESpace & Uh,const FESpace & Vh,bool sym,bool
 template<class R> inline void ConjArray( R  *v, int n) 
 {
   for (int i=0;i<n;++i)
-    v[i] = conj(v[i]);
+    v[i] = RNM::conj(v[i]);
 }
 template<> inline void ConjArray<double>(double *v, int n) {}
 template<> inline void ConjArray<float>(float *v, int n) {}
@@ -1206,8 +1252,8 @@ bool MatriceMorse<R>::addMatTo(R coef,std::map< pair<int,int>, R> &mij,bool tran
        for ( k=lg[i];k<lg[i+1];k++)
          {
            j=cl[k];
-           R cij =  coef* ( cnj ? conj(a[k]) : a[k]);
-           if(norm(cij)>eps0)
+           R cij =  coef* ( cnj ? RNM::conj(a[k]) : a[k]);
+           if(RNM::norm2(cij)>eps0)
            {
             mij[ij_mat(trans,ii00,jj00,i,j)] += cij ;
            if (i!=j)
@@ -1222,9 +1268,9 @@ bool MatriceMorse<R>::addMatTo(R coef,std::map< pair<int,int>, R> &mij,bool tran
        for ( k=lg[i];k<lg[i+1];k++)
          {
            j=cl[k];
-           R cij =  coef* ( cnj ? conj(a[k]) : a[k]);
+           R cij =  coef* ( cnj ? RNM::conj(a[k]) : a[k]);
 
-           if(norm(cij)>eps0)
+           if(RNM::norm2(cij)>eps0)
            mij[ij_mat(trans,ii00,jj00,i,j)] += cij;
          }
    }
@@ -1282,7 +1328,7 @@ template<class R>
 	    {
 	      for (int k=lg[i];k<lg[i+1];k++)
 		{   int j=cl[k];
-		    if( j<this->m && norm(a[k]))		    
+		    if( j<this->m && RNM::norm2(a[k]))		    
 			++nc;		   
 		}
 		nlg[i+1]=nc;
@@ -1296,7 +1342,7 @@ template<class R>
 	      for (int k=lg[i];k<lg[i+1];k++)
 		{
 		    int j=cl[k];
-		    if(i<this->n && j<this->m && norm(a[k]))
+		    if(i<this->n && j<this->m && RNM::norm2(a[k]))
 			++nc ;
 		}
 		nlg[i+1]=nc;
@@ -1313,7 +1359,7 @@ template<class R>
 	  for (int i=0;i<nm;i++)
 	      for (int k=lg[i];k<lg[i+1];k++)
 		{   int j=cl[k];
-		    if( j<this->m && norm(a[k]))		    
+		    if( j<this->m && RNM::norm2(a[k]))		    
 		      {na[nc]=a[k];
 		       ncl[nc++]=j;}
 		}
@@ -1325,7 +1371,7 @@ template<class R>
 	      for (int k=lg[i];k<lg[i+1];k++)
 		{
 		    int j=cl[k];
-		    if( j<this->m && norm(a[k]))
+		    if( j<this->m && RNM::norm2(a[k]))
 		      {na[nc]=a[k];
 		       ncl[nc++]=j;}
 		}
@@ -1393,7 +1439,7 @@ template<class RA>
        for (int k=lg[i];k<lg[i+1];k++)
          {    
            int j=cl[k];
-           if(norm(a[k])<eps0) continue;
+           if(RNM::norm2(a[k])<eps0) continue;
            int ii[2],jj[2];
            ii[0]=i;ii[1]=j;
            jj[0]=j;jj[1]=i;
@@ -1412,7 +1458,7 @@ template<class RA>
                      bjk=B(kz,j);
                    else
                       bjk=B(j,kz);
-                   if( norm(bjk)>eps0 && (!sym || kz<=i))
+                   if( RNM::norm2(bjk)>eps0 && (!sym || kz<=i))
                      sij.insert(make_pair(i,kz));
                   }
             }
@@ -1462,7 +1508,7 @@ template<class RA>
          {    
            int j=cl[k];
            RAB aij = a[k];
-           if(norm(aij) <eps0 ) continue;
+           if(RNM::norm2(aij) <eps0 ) continue;
            int ii[2],jj[2];
            ii[0]=i;ii[1]=j;
            jj[0]=j;jj[1]=i;
@@ -1482,7 +1528,7 @@ template<class RA>
                    else
                       bjk=B(j,k);
                 //   cout << i << "," << "," << j << "," << k << " " << aij << " " << bjk << endl;
-                   if( norm( bjk)> eps0  && (!sym || k<=i))
+                   if( RNM::norm2( bjk)> eps0  && (!sym || k<=i))
                        AB(i,k) += aij*bjk;
                   }
             }
@@ -1655,7 +1701,7 @@ double MatriceMorse<R>::psor(KN_<R> & x,const  KN_<R> & gmin,const  KN_<R> & gma
         R dx  = (xnew - x[i])*omega ;
         R xi = RNM::Min(RNM::Max(x[i]+dx,gmin[i]),gmax[i]);
         dx = x[i]- xi;
-        err = Max(err, norm(dx));
+        err = Max(err, RNM::norm2(dx));
         x[i] = xi;
         }
    }  return sqrt(err);
@@ -1695,7 +1741,7 @@ void MatriceMorse<R>::setdiag(const KN_<R> & x)
     {
       R * p= pij(i,i);
       if(p)     *p = x[i];
-      else ffassert( norm(x[i]) < 1e-30);}
+      else ffassert( RNM::norm2(x[i]) < 1e-30);}
 }
 template<class R>
 void MatriceMorse<R>::getdiag(KN_<R> & x) const 
@@ -1754,14 +1800,20 @@ R MatriceProfile<R>::pscal(const KN_<R> & x,const KN_<R> & y)
       
  if (L && pL )    
    for (kf=pL[0],i=0;  i<this->n;   i++  )  
-     for ( k=kf,kf=pL[i+1], j=i-kf+k;   k<kf; j++,  k++  )
-       sum += L[k]*x[i]*y[j],throwassert(i>=0 && i <this->n && j >=0 && j < this->m && k>=0 && k < pL[this->n]);
-       
+     { 
+       k=kf;
+       kf=pL[i+1];
+       for ( j=i-kf+k;   k<kf; j++,  k++  )
+	 sum += L[k]*x[i]*y[j],throwassert(i>=0 && i <this->n && j >=0 && j < this->m && k>=0 && k < pL[this->n]);
+     }
  if (U && pU)     
    for (kf=pU[0],j=0;  j<this->m;  j++)  
-     for (k=kf,kf=pU[j+1], i=j-kf+k;   k<kf; i++,  k++  )
-       sum += U[k]*x[i]*y[j],throwassert(i>=0 && i <this->n && j >=0 && j < this->m &&  k>=0 && k < pU[this->n]);
- 
+     {
+       k=kf;
+       kf=pU[j+1];
+       for ( i=j-kf+k;   k<kf; i++,  k++  )
+	 sum += U[k]*x[i]*y[j],throwassert(i>=0 && i <this->n && j >=0 && j < this->m &&  k>=0 && k < pU[this->n]);
+     }
  return sum;
 }
 
