@@ -149,13 +149,19 @@ inline void Check_Kn(const char * str,const char * file,int line)
 //  add size of the matrix in VirtualMatrix class.
 //   mars 2010 add  unset KNM case ...
 // ----------------
+
+namespace RNM {
 inline double  conj(const double & x){return x;}
 inline float  conj(const float &x){return x;}
 inline long  conj(const long &x){return x;}
 inline double  real(const double &x){return x;}
 inline float  real(const float &x){return x;}
-
-namespace RNM {
+    template<class T> T  real(const complex<T>& v){ return std::real(v);}
+inline double  norm2(const double x){return x*x;}
+inline float  norm2(const float x){return x*x;}
+template<class T> T  norm2(const complex<T>& v){ return norm(v);}
+    
+template<class T> inline complex<T>  conj(const complex<T>& v){ return std::conj<T>(v);}
 template<class T> inline T Min (const T &a,const T &b){return a < b ? a : b;}
 template<class T> inline T Max (const T &a,const T & b){return a > b ? a : b;}
 template<class T> inline T Abs (const T &a){return a <0 ? -a : a;}
@@ -633,7 +639,12 @@ class KNM_: public KN_<R> {
   R & operator()(int i,int j)     const   
             { return this->v[indexij(i,j)];}
             
-            
+   KN_<R> operator()(const SubArray & sa,long j) const 
+    { return this->operator()(':',j)(sa);}  // sub array 
+   
+  KN_<R> operator()(long i,const SubArray & sb) const 
+    { return  this->operator()(i,':')(sb);} 
+    
   KN_<R> operator()(const char,long j    )  const   // une colonne j  ('.',j)
             { return KN_<R>(&this->v[this->index(shapej.index(j))],shapei*this->step);} 
   KN_<R> operator()(long i    ,const char)  const   // une ligne i  (i,'.')
@@ -952,44 +963,44 @@ class KN :public KN_<R> { public:
    KN& operator /= (R*  a) { CheckSet(); return operator/=(KN_<R>(a,this->n));}  
   
    KN& operator  =(const SetArray<R> & u)  
-     { if(this->unset()) set(new R[u.size()],u.size(),0,0); KN_<R>::operator= (u);return *this;}
+     { if(this->unset()) this->set(new R[u.size()],u.size(),0,0); KN_<R>::operator= (u);return *this;}
    KN& operator +=(const SetArray<R> & u)  
-     { if(this->unset()) set(new R[u.size()],u.size(),0,0); KN_<R>::operator+= (u);return *this;}
+     { if(this->unset()) this->set(new R[u.size()],u.size(),0,0); KN_<R>::operator+= (u);return *this;}
    KN& operator -=(const SetArray<R> & u)    
-     { if(this->unset()) set(new R[u.size()],u.size(),0,0); KN_<R>::operator-= (u);return *this;}
+     { if(this->unset()) this->set(new R[u.size()],u.size(),0,0); KN_<R>::operator-= (u);return *this;}
    KN& operator *=(const SetArray<R> & u)  
-     { if(this->unset()) set(new R[u.size()],u.size(),0,0); KN_<R>::operator*= (u);return *this;}
+     { if(this->unset()) this->set(new R[u.size()],u.size(),0,0); KN_<R>::operator*= (u);return *this;}
    KN& operator /=(const SetArray<R> & u)  
-     { if(this->unset()) set(new R[u.size()],u.size(),0,0); KN_<R>::operator/= (u);return *this;}
+     { if(this->unset()) this->set(new R[u.size()],u.size(),0,0); KN_<R>::operator/= (u);return *this;}
 
    KN& operator =(const_R a)  
-        { if(this->unset()) set(new R[1],1,0,0); KN_<R>::operator= (a);return *this;}
+        { if(this->unset()) this->set(new R[1],1,0,0); KN_<R>::operator= (a);return *this;}
    KN& operator =(const KN_<R>& a)  
-        { if(this->unset()) set(new R[a.N()],a.N()); KN_<R>::operator= (a);return *this;}                
+        { if(this->unset()) this->set(new R[a.N()],a.N()); KN_<R>::operator= (a);return *this;}                
    KN& operator =(const KN<R>& a)  
-        { if(this->unset()) set(new R[a.N()],a.N()); KN_<R>::operator= (a);return *this;}                
+        { if(this->unset()) this->set(new R[a.N()],a.N()); KN_<R>::operator= (a);return *this;}                
    KN& operator =(const Add_KN_<R> & u)  
-        { if(this->unset()) set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
+        { if(this->unset()) this->set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
    KN& operator =(const DotStar_KN_<R> & u)  
-        { if(this->unset()) set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
+        { if(this->unset()) this->set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
    KN& operator =(const if_KN_<R> & u)  
-        { if(this->unset()) set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
+        { if(this->unset()) this->set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
    KN& operator =(const ifnot_KN_<R> & u)  
-        { if(this->unset()) set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
+        { if(this->unset()) this->set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
    KN& operator =(const DotSlash_KN_<R> & u)  
-        { if(this->unset()) set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
+        { if(this->unset()) this->set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
    KN& operator =(const Sub_KN_<R> & u)  
-        { if(this->unset()) set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
+        { if(this->unset()) this->set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
    KN& operator =(const Mulc_KN_<R> & u)  
-        { if(this->unset()) set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
+        { if(this->unset()) this->set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
    KN& operator =(const Add_Mulc_KN_<R> & u)  
-        { if(this->unset()) set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
+        { if(this->unset()) this->set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
    KN& operator =(const if_arth_KN_<R> & u)  
-        { if(this->unset()) set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
+        { if(this->unset()) this->set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
         
         
    KN& operator =(const Mul_KNM_KN_<R> & u) 
-        { if(this->unset()) set(new R[u.b.N()],u.b.N());KN_<R>::operator=(u);return *this;}
+        { if(this->unset()) this->set(new R[u.b.N()],u.b.N());KN_<R>::operator=(u);return *this;}
 //   KN& operator =(const MatriceCreuseMulKN_<R> & Ax) 
 //       {if(this->unset()) set(new R[Ax.v.N()],Ax.v.N()); KN_<R>::operator=(Ax);return *this;}
 //   KN& operator +=(const MatriceCreuseMulKN_<R> & Ax) 
@@ -998,20 +1009,20 @@ class KN :public KN_<R> { public:
 //       { if(this->unset()) set(new R[A1x.v.N()],A1x.v.N());KN_<R>::operator=(A1x);return *this;}
   // correcton aout 2007 FH  add N,M flied in VirtualMatrice
    KN& operator =(const typename VirtualMatrice<R>::plusAx & Ax)  
-        { if(this->unset() && Ax.A->N ) set(new R[Ax.A->N],Ax.A->N);KN_<R>::operator=(Ax);return *this;}
+        { if(this->unset() && Ax.A->N ) this->set(new R[Ax.A->N],Ax.A->N);KN_<R>::operator=(Ax);return *this;}
    KN& operator =(const typename VirtualMatrice<R>::solveAxeqb & Ab)  
-        { if(this->unset()) set(new R[Ab.b.N()],Ab.b.N());KN_<R>::operator=(Ab);return *this;}
+        { if(this->unset()) this->set(new R[Ab.b.N()],Ab.b.N());KN_<R>::operator=(Ab);return *this;}
    KN& operator +=(const typename  VirtualMatrice<R>::plusAx & Ax)  
   { if(this->unset()  && Ax.A->N) {
-        set(new R[Ax.A->N],Ax.A->N);
+        this->set(new R[Ax.A->N],Ax.A->N);
         KN_<R>::operator=(R());}
     KN_<R>::operator+=(Ax);
     return *this;}
    KN& operator =(const typename VirtualMatrice<R>::plusAtx & Ax)  
-        { if(this->unset()&&Ax.A->M) set(new R[Ax.A->M],Ax.A->M);KN_<R>::operator=(Ax);return *this;}
+        { if(this->unset()&&Ax.A->M) this->set(new R[Ax.A->M],Ax.A->M);KN_<R>::operator=(Ax);return *this;}
    KN& operator +=(const typename VirtualMatrice<R>::plusAtx & Ax)  
   { if(this->unset()&&Ax.A->M) {
-       set(new R[Ax.A->M],Ax.A->M);
+       this->set(new R[Ax.A->M],Ax.A->M);
       KN_<R>::operator=(R());}
       KN_<R>::operator+=(Ax);
      return *this;}
@@ -1123,7 +1134,8 @@ class KN :public KN_<R> { public:
 //          { return   (KN<const_R> &) *this;}
 //    operator KN<const_R> const & ()  const 
 //          { return (const KN<const_R>& ) *this;}
-  void init(long nn) {this->n=nn;this->step=1;this->next=-1;this->v=new R[nn];}
+    static void fill0(R *v,int n) { if(n && v) for(int i=0;i<n;++i) v[i]=R();} 
+    void init(long nn) {this->n=nn;this->step=1;this->next=-1;this->v=new R[nn];fill0(this->v,this->n) ;}
   void init() {this->n=0;this->step=1;this->next=-1;this->v=0;}
   void init(const KN_<R> & a){init(a.N()); operator=(a);}
   void resize(long nn) {
@@ -1147,7 +1159,7 @@ class KN :public KN_<R> { public:
 
 template<class R>
 class KNM: public KNM_<R>{ public:
-
+  KNM() :KNM_<R>(0,0,0){}
   KNM(long nn,long mm) 
         :KNM_<R>(new R[nn*mm],nn,mm){}
    KNM(const KNM<R> & u)  // PB si stepi ou stepj nulle
@@ -1231,28 +1243,28 @@ class KNM: public KNM_<R>{ public:
     long n = this->shapei.n;
     long m = this->shapej.n;
     
-    if( n !=nn && m != mm) 
+    if( (n !=nn) || ( m != mm))  // correct FH Jav 2012 ..
      {
-    KNM_ <R> old(*this); 
-    long no=std::min(n,nn);
-    long mo=std::min(m,mm);
-    R *vo=this->v;
+       KNM_ <R> old(*this); 
+       long no=std::min(n,nn);
+       long mo=std::min(m,mm);
+       R *vo=this->v;
+       
+       // new mat 
+       ShapeOfArray::init(kk);
+       this->v=new R[this->n];
+       this->shapei.init(nn,1,nn);
+       this->shapej.init(mm,nn,1);
+       
+       if(this->v && vo)  // copy
+	 (*this)(SubArray(no),SubArray(mo)) = old(SubArray(no),SubArray(mo));
+       
+       delete []vo;
+     }
     
-    // new mat 
-    ShapeOfArray::init(kk);
-    this->v=new R[this->n];
-    this->shapei.init(nn,1,nn);
-    this->shapej.init(mm,nn,1);
-    
-    if(this->v && vo)  // copy
-        (*this)(SubArray(no),SubArray(mo)) = old(SubArray(no),SubArray(mo));
-      
-    delete []vo;
-    }
-        
-   }
-    void destroy(){assert(this->next<0);  if(this->next++ ==-1) {delete [] this->v; this->v=0;this->n=0;}} 
-    void increment() {assert(this->next<0);  this->next--;}
+  }
+  void destroy(){assert(this->next<0);  if(this->next++ ==-1) {delete [] this->v; this->v=0;this->n=0;}} 
+  void increment() {assert(this->next<0);  this->next--;}
     
 //  void destroy(){delete [] this->v;this->n=0 ;}
 
