@@ -24,15 +24,17 @@ template<class T> inline T Min (const T &a,const T & b,const T & c){return Min(M
 
 //#include "ufunction.hpp" 
 #include "ufunction.hpp" 
-inline double norm(double x){return x*x;} 
-inline float norm(float x){return x*x;}
+
 #include <utility>
 #include <algorithm>
+#include <complex>
 
 // definition R
 namespace Fem2D 
 {
-
+inline double norm(double x){return x*x;} 
+inline float norm(float x){return x*x;}
+template<class T> T  norm(const complex<T> &x){return std::norm(x);}
 
 #include "R1.hpp"
 #include "R2.hpp"
@@ -291,7 +293,7 @@ public:
       if (i<0) ffassert(i>=0);
       else if  (i<3) return SortedTriplet(vertices[i]-v0);
       else if( (i-=3)<3) return SortedTriplet( &Edge(i,0)-v0, &Edge(i,1)-v0);
-      else if( (i==0) ) return SortedTriplet( vertices[0]-v0, vertices[1]-v0, vertices[2]-v0) ;
+      else if( i==0 ) return SortedTriplet( vertices[0]-v0, vertices[1]-v0, vertices[2]-v0) ;
       else ffassert(0);
   }
   
@@ -359,7 +361,7 @@ public:
   SortedTriplet what(int i,Vertex *v0,TBoundaryEdge * t0) { 
       if (i<0) ffassert(i>=0);
       else if  (i<2) return SortedTriplet(vertices[i]-v0);
-      else if( (i==0) ) return SortedTriplet( vertices[0]-v0, vertices[1]-v0) ;
+      else if( i==0 ) return SortedTriplet( vertices[0]-v0, vertices[1]-v0) ;
       else ffassert(0);
   }
   
@@ -406,6 +408,8 @@ typedef TMortar<R2> Mortar;
  
 class FQuadTree;
 
+  // <<class Mesh>>
+
 class Mesh: public RefCounter { 
 public:
   
