@@ -95,7 +95,7 @@ template<class A,class B>  A Build(B b) {  return A(b);}
   
 
 
-long Exit(long i) {throw(ErrorExec("Exit",i));return 0;}
+long Exit(long i) {throw(ErrorExit("Exit",i));return 0;}
 bool Assert(bool b) {if (!b) throw(ErrorExec("exec assert",1));return true;}
   
 inline void MyAssert(int i,char * ex,char * file,long line)
@@ -488,7 +488,7 @@ struct  MIMul {
       {
         if (mia && a->EvaluableWithOutStack() )
           {
-            A va = GetAny<A>((*a)(0));
+            A va = GetAny<A>((*a)(NullStack));
            // cout << " va = " << va << endl;
             if ( va == A() )
              { 
@@ -498,7 +498,7 @@ struct  MIMul {
           }
         if (mib && b->EvaluableWithOutStack() )
           {
-            B vb = GetAny<B>((*b)(0));
+            B vb = GetAny<B>((*b)(NullStack));
             // cout << " vb = " << vb << endl;
             if ( vb == B() ) 
             { //cout << " vb = " << vb << endl;
@@ -858,6 +858,8 @@ istream *Getline(istream * f, string ** s)
 {
     if( *s==0) *s=new string;
     getline(*f,**s);
+    size_t l = (**s).length();
+    if( l > 0 && ((**s)[l-1]=='\r')) (**s).resize(l-1); //
        return f;    
 }
 // Fin Add ne marche pas ....
@@ -1440,12 +1442,13 @@ void Init_map_type()
      //     Global.Add("log10","(",new OneOperator1_<Complex>(log10));
      //     Global.Add("tan","(",new OneOperator1_<Complex>(tan));
      Global.Add("exp","(",new OneOperator1_<Complex>(exp));
-     Global.Add("pow","(",new OneOperator2_<Complex,Complex>(pow));
+     //Complex (* powcc  )( const  Complex &, const Complex &) =pow;
+     Global.Add("pow","(",new OneOperator2_<Complex,Complex>(pow ));
      Global.Add("sqrt","(",new OneOperator1_<Complex>(sqrt,0));
      Global.Add("conj","(",new OneOperator1_<Complex>(conj,0));
-     Global.Add("conj","(",new OneOperator1_<double>(conj,1));
+     Global.Add("conj","(",new OneOperator1_<double>(RNM::conj,1));
      TheOperators->Add("\'",new OneOperator1_<Complex>(conj,0));       
-     TheOperators->Add("\'",new OneOperator1_<double>(conj,1));       //  add F.  Feb 2010  of conj of varf.. 
+     TheOperators->Add("\'",new OneOperator1_<double>(RNM::conj,1));       //  add F.  Feb 2010  of conj of varf.. 
      
      
      Global.Add("imag","(",new OneOperator1_<double,Complex>(Imag));
@@ -1554,7 +1557,7 @@ C_F0  opVI::code2(const basicAC_F0 &args) const
 	bool bb=p->EvaluableWithOutStack();
 	//cout << bb << " " <<  * p <<  endl;
 	CompileError(" [...][p], The p must be a constant , sorry");}
-        long pv = GetAny<long>((*p)(0));
+        long pv = GetAny<long>((*p)(NullStack));
     bool ta =args[0].left()==atype<TransE_Array>();
     const TransE_Array * tea=0;
     const E_Array * ea=0;
@@ -1563,7 +1566,13 @@ C_F0  opVI::code2(const basicAC_F0 &args) const
     assert( ea || tea );
     const E_Array & a=  ta ? *tea->v : *ea;
    // cout << " pv =" << pv << " size = "<< a.size() << endl;
-    ffassert(pv >=0 && pv <a.size());
+    if(!(pv >=0 && pv <a.size()))
+    {
+      cerr << "\n\nerror [ ... ][" << pv <<" ] " << " the  size of [ ...]  is "<< a.size() << endl;
+      lgerror(" bound of  [ .., .. , ..][ . ] operation  ");
+    }
+    
+    //ffassert(pv >=0 && pv <a.size());
     return (* a.v)[pv];
 }
 
@@ -1728,121 +1737,123 @@ C_F0  opColumn::code2(const basicAC_F0 &args) const
     if( tb)  teb = dynamic_cast<const TransE_Array*>((Expression) args[1]);
     else eb = dynamic_cast<const E_Array*>((Expression) args[1]);
     
-   // ffassert( ea || tea );
-
+    // ffassert( ea || tea );
+    
     if( (eb || teb) && ( ea || tea ) )
     {
-    const E_Array & a=  ta ? *tea->v : *ea;
-    const E_Array & b=  tb ? *teb->v : *eb;
-    int ma =1;
-    int mb =1;
-    int na=a.size();
-    int nb=b.size();
-    if(na <1 && nb < 1) CompileError(" empty array  [ ...]':[ ...  ]  ");
-    bool mab= b[0].left()==atype<E_Array>();
-    bool maa= a[0].left()==atype<E_Array>();
-    if(maa) {
-	ma= a[0].LeftValue()->nbitem();
-	for (int i=1;i<na;i++)
-	    if( ma != (int) a[i].LeftValue()->nbitem())
-		CompileError(" first matrix with variable number of columm");
+        const E_Array & a=  ta ? *tea->v : *ea;
+        const E_Array & b=  tb ? *teb->v : *eb;
+        int ma =1;
+        int mb =1;
+        int na=a.size();
+        int nb=b.size();
+        if(na <1 && nb < 1) CompileError(" empty array  [ ...]':[ ...  ]  ");
+        bool mab= b[0].left()==atype<E_Array>();
+        bool maa= a[0].left()==atype<E_Array>();
+        if(maa) {
+            ma= a[0].LeftValue()->nbitem();
+            for (int i=1;i<na;i++)
+                if( ma != (int) a[i].LeftValue()->nbitem())
+                    CompileError(" first matrix with variable number of columm");
+            
+        }
+        if(mab) {
+            mb= b[1].LeftValue()->nbitem();
+            for (int i=1;i<nb;i++)
+                if( mb != (int) b[i].LeftValue()->nbitem())
+                    CompileError(" second matrix with variable number of columm");
+        }
+        int na1=na,ma1=ma,nb1=nb,mb1=mb;
+        if(ta) RNM::Exchange(na1,ma1);
+        if(tb) RNM::Exchange(nb1,mb1);
         
-    }
-    if(mab) {
-	mb= b[1].LeftValue()->nbitem();
-	for (int i=1;i<nb;i++)
-	    if( mb != (int) b[i].LeftValue()->nbitem())
-		CompileError(" second matrix with variable number of columm");
-    }
-    int na1=na,ma1=ma,nb1=nb,mb1=mb;
-    if(ta) RNM::Exchange(na1,ma1);
-    if(tb) RNM::Exchange(nb1,mb1);
-    
-    KNM<CC_F0> A(na1,ma1), B(nb1,mb1);
-    if ( (na1!=nb1 ) || (ma1 != mb1) || (na1 * ma1 ==0)  )
-    {
-	cout << "\n   formal  array or matrix : [ .. ] : [ .. ]   " << endl;
-	cout << " first  array :  matrix " << maa << " trans " << ta << " " << na << "x" << ma <<endl;
-	cout << " second array :  matrix " << mab << " trans " << tb << " " << nb << "x" << mb <<endl;
-	CompileError(" no same size  [ ...] : [ ...  ] sorry ");
-    }
-    
-    if(maa)
-	for (int i=0;i<na;++i)
-	{
-	    const E_Array * li=  dynamic_cast<const E_Array *>(a[i].LeftValue());
-	    ffassert(li);
-	    for (int j=0; j<ma;++j)
-		if(!ta)  A(i,j) = (*li)[j];
-		else     A(j,i) = TryConj((*li)[j]);
-	}
-    else
-	for (int i=0;i<na;++i)
-	    if(!ta)  A(i,0) = a[i];
-	    else     A(0,i) = TryConj(a[i]);
-    
-    if(mab)
-	for (int i=0;i<nb;++i)
-	{
-	    const E_Array * li=  dynamic_cast<const E_Array *>(b[i].LeftValue());
-	    ffassert(li);
-	    for (int j=0; j<mb;++j)
-		if(!tb)  B(i,j) = (*li)[j];
-		else     B(j,i) = TryConj((*li)[j]);
-	}
-    else
-	for (int i=0;i<nb;++i)
-	    if(!tb)  B(i,0) = b[i];
-	    else     B(0,i) = TryConj(b[i]);
-    
-    //KNM<CC_F0> C(na1,mb1);
-    CC_F0 s,aibi;
-    
-    for (int i=0;i<na1;++i)
-      for (int j=0;j<ma1;++j)
-	{
-		aibi = C_F0(TheOperators,"*",A(i,j),B(i,j));
-            if( (i==0) && (j==0))
-                s = aibi; 
-            else 
-            s = C_F0(TheOperators,"+",s,aibi);
-	};
- //   if( na1==1 && mb1 ==1)
-	return s;
+        KNM<CC_F0> A(na1,ma1), B(nb1,mb1);
+        if ( (na1!=nb1 ) || (ma1 != mb1) || (na1 * ma1 ==0)  )
+        {
+            cout << "\n   formal  array or matrix : [ .. ] : [ .. ]   " << endl;
+            cout << " first  array :  matrix " << maa << " trans " << ta << " " << na << "x" << ma <<endl;
+            cout << " second array :  matrix " << mab << " trans " << tb << " " << nb << "x" << mb <<endl;
+            CompileError(" no same size  [ ...] : [ ...  ] sorry ");
+        }
+        
+        if(maa)
+            for (int i=0;i<na;++i)
+            {
+                const E_Array * li=  dynamic_cast<const E_Array *>(a[i].LeftValue());
+                ffassert(li);
+                for (int j=0; j<ma;++j)
+                    if(!ta)  A(i,j) = (*li)[j];
+                    else     A(j,i) = TryConj((*li)[j]);
+            }
+        else
+            for (int i=0;i<na;++i)
+                if(!ta)  A(i,0) = a[i];
+                else     A(0,i) = TryConj(a[i]);
+        
+        if(mab)
+            for (int i=0;i<nb;++i)
+            {
+                const E_Array * li=  dynamic_cast<const E_Array *>(b[i].LeftValue());
+                ffassert(li);
+                for (int j=0; j<mb;++j)
+                    if(!tb)  B(i,j) = (*li)[j];
+                    else     B(j,i) = TryConj((*li)[j]);
+            }
+        else
+            for (int i=0;i<nb;++i)
+                if(!tb)  B(i,0) = b[i];
+                else     B(0,i) = TryConj(b[i]);
+        
+        //KNM<CC_F0> C(na1,mb1);
+        CC_F0 s,aibi;
+        
+        for (int i=0;i<na1;++i)
+            for (int j=0;j<ma1;++j)
+            {
+                aibi = C_F0(TheOperators,"*",A(i,j),B(i,j));
+                if( (i==0) && (j==0))
+                    s = aibi; 
+                else 
+                    s = C_F0(TheOperators,"+",s,aibi);
+            };
+        //   if( na1==1 && mb1 ==1)
+        return s;
     }
     else if ( ea || tea )
-    {
-        
+    { // modif 2 /08/  2013  FH .. bug in [ a0,a1,... ]'*b 
+        //  [a0,a1,... ]*b  or [ a0,a1,... ]'*b  => [ a0*b',a1*b',
         const E_Array & a=  ta ? *tea->v : *ea;
         int na=a.size();
         AC_F0  v;
         v = 0; // empty
-	for (int i=0;i<na;++i)
-	    v += C_F0(TheOperators,"*",ta ? TryConj(a[i]) : a[i],args[1]) ;
-	return ta ? C_F0(TheOperators,"\'",C_F0(TheOperators,"[]",v)) :   C_F0(TheOperators,"[]",v);
-    
+        C_F0 b =ta ? TryConj(args[1]) :args[1]; 
+        for (int i=0;i<na;++i)
+        v += C_F0(TheOperators,"*",a[i],b)  ;            
+        return ta ? C_F0(TheOperators,"\'",C_F0(TheOperators,"[]",v)) :   C_F0(TheOperators,"[]",v);
+        
     }
     else if(eb || teb)
-     {
-         const E_Array & b=  tb ? *teb->v : *eb;
-         int nb=b.size();
-         AC_F0  v;
-         v = 0; // empty
-         for (int i=0;i<nb;++i)
-             v += C_F0(TheOperators,"*",args[0],tb ? TryConj(b[i]) : b[i]) ;
-         return tb ? C_F0(TheOperators,"\'",C_F0(TheOperators,"[]",v)) :   C_F0(TheOperators,"[]",v);
-
-     }
+    {  // modif 2 /08/  2013  FH .. bug in a*[ b0,b1,... ]'
+        const E_Array & b=  tb ? *teb->v : *eb;
+        int nb=b.size();
+        C_F0 a =tb ? TryConj(args[0]) :args[0]; 
+        AC_F0  v;
+        v = 0; // empty
+        for (int i=0;i<nb;++i)
+            v += C_F0(TheOperators,"*",a,b[i]) ;
+        return tb ? C_F0(TheOperators,"\'",C_F0(TheOperators,"[]",v)) :   C_F0(TheOperators,"[]",v);
+        
+    }
     else ffassert(0); 
-/*
-    cout << "   formal : array or matrix : [ .. ] : [ .. ]   " << na << "x" << nb << endl;
-    cout << "   formal : array or matrix : [ .. ] : [ .. ]   " <<  endl;
-    cout << " first  array :  matrix " << maa << " trans " << ta << " " << na << "x" << ma <<endl;
-    cout << " second array :  matrix " << mab << " trans " << tb << " " << nb << "x" << mb <<endl;
-    CompileError("  not implemented sorry ..... (FH) to do ???? ");
-   
- */
-     return C_F0();
+    /*
+     cout << "   formal : array or matrix : [ .. ] : [ .. ]   " << na << "x" << nb << endl;
+     cout << "   formal : array or matrix : [ .. ] : [ .. ]   " <<  endl;
+     cout << " first  array :  matrix " << maa << " trans " << ta << " " << na << "x" << ma <<endl;
+     cout << " second array :  matrix " << mab << " trans " << tb << " " << nb << "x" << mb <<endl;
+     CompileError("  not implemented sorry ..... (FH) to do ???? ");
+     
+     */
+    return C_F0();
 }
 
 
