@@ -37,7 +37,7 @@ class  addingInitFunct {  public:
 } ;
 
 //
-
+#if WIN32
 #define LOADINITIO {					\
     streambuf * so =ffapi::cout()->rdbuf() ;		\
     streambuf * si =ffapi::cin()->rdbuf() ;		\
@@ -45,11 +45,20 @@ class  addingInitFunct {  public:
     if( so &&  cout.rdbuf() != so ) cout.rdbuf(so);	\
     if( si &&  cin.rdbuf() != si ) cin.rdbuf(si);	\
     if( se &&  cerr.rdbuf() != se ) cerr.rdbuf(se);	\
-    stdout = ffapi::stdout();\
-    stderr = ffapi::stderr();\
-    stdin = ffapi::stdin();\
 } 
-
+#else
+#define LOADINITIO {					\
+    streambuf * so =ffapi::cout()->rdbuf() ;		\
+    streambuf * si =ffapi::cin()->rdbuf() ;		\
+    streambuf * se =ffapi::cerr()->rdbuf() ;		\
+    if( so &&  cout.rdbuf() != so ) cout.rdbuf(so);	\
+    if( si &&  cin.rdbuf() != si ) cin.rdbuf(si);	\
+    if( se &&  cerr.rdbuf() != se ) cerr.rdbuf(se);	\
+    stdout = ffapi::ffstdout();\
+    stderr = ffapi::ffstderr();\
+    stdin = ffapi::ffstdin();\
+} 
+#endif
 
   
 #define LOADINITNM(EXEC,NM)						\
