@@ -58,11 +58,15 @@ void  mylex::Add(Key k,int i)
   Check(!i,k,"mot clef");
   Add(k,i,0); 
 }
+
 void  mylex::Add(Key k,aType t)   
 {
   Check(!t,k,"type");
+
+  // TYPE defined at [[file:../lglib/lg.ypp::token type TYPE]]
   Add(k,TYPE,t);
 }
+
 void  mylex::AddF(Key k,aType t)  
 {
   Check(!t,k,"FUNCTION");
@@ -88,7 +92,7 @@ bool mylex::InMotClef  (aType & t, int & r) const {
 void  mylex::Add(Key k,int r,aType t){ 
   iterator ii= MotClef.find(k);
   ffassert(ii==MotClef.end());
-  MotClef.insert(make_pair<const Key,Value>(k,make_pair(r,t))); }
+  MotClef.insert(pair<const Key,Value>(k,Value(r,t))); }
 
 void mylex::dump(ostream & f ) 
 {
@@ -265,7 +269,10 @@ int mylex::basescan()
 	      ccc= source().peek(); 
               switch (cc) {
               case 'n': buf[i]='\n';break;
+              case 'r': buf[i]='\r';break;
               case 'f': buf[i]='\f';break;
+              case 't': buf[i]='\t';break;
+              case 'a': buf[i]='\a';break;
               case 10:
               case 13:
 		cc='\n';
@@ -393,17 +400,20 @@ int mylex::scan1()
   return ret;
 }    
 
+// <<mylex::scan>>
 int mylex::scan(int lvl)
 {
  
   int ret= scan1(); 
   
-      
+  // ID defined at [[file:../lglib/lg.ypp::token str ID]]
   if ( ret == ID) {
     if (! InMotClef(plglval->type,ret))  {
       int ft = FindType(buf);
-      //      if( ft) cout << "(  ft == " << ft << " ) "<< endl;
+
+      // FESPACE, FESPACE1, FESPACE3 defined at [[file:../lglib/lg.ypp::token str FESPACE]]
       int feid3[4]  ={ ID,FESPACE1,FESPACE,FESPACE3};
+
       assert ( ft >= 0 && ft <= 3)  ;
       ret =  feid3[ft];      
       plglval->str = newcopy(buf);
@@ -418,7 +428,8 @@ int mylex::scan(int lvl)
   
   return ret;
 }
-  string mylex::token() const
+
+string mylex::token() const
   {
    int i=-1;
    string f;
@@ -628,7 +639,7 @@ bool mylex::CallMacro(int &ret)
 		  }
 		  if(debugmacro)
 		cout << "macro arg "<< k << " :" << macroparm[k] << " -> " <<  p << endl;
-	      lp.insert(make_pair<string,string>(macroparm[k],p));
+	      lp.insert(pair<string,string>(macroparm[k],p));
 	      //lp[macroparm[k]] = p; 
 	    }
 	}
@@ -702,9 +713,10 @@ void  mylex::xxxx::open(mylex *lex,const char * ff)
 
     lgerror("lex: Error input openning file ");};
 }
-void  mylex::xxxx::readin(mylex *lex,const string & s,const string *name)//,int nbparam,int bstackparam) 
+void  mylex::xxxx::readin(mylex *lex,const string & s,const string *name, int macroargs)//,int nbparam,int bstackparam)
 {
   filename=name;
+  macroarg=macroargs;
   l=0;
   nf=f= new istringstream(s.c_str()); 
   
@@ -716,7 +728,7 @@ void  mylex::xxxx::readin(mylex *lex,const string & s,const string *name)//,int
 void mylex::xxxx::close() 
 { 
   if( nf)  delete nf;
-  if (filename) delete filename;
+  if (filename && (macroarg==0) ) delete filename;
   
 }
 void mylex::input(const char *  filename) 
