@@ -411,7 +411,7 @@ basicAC_F0::name_and_type  SetMatrix_Op<R>::name_param[]= {
 /*
    {   "paramint",&typeid(KN<int>)}, // Add J. Morice 02/09 
    {   "paramdouble",&typeid(KN<double>)},
->>>>>>> 1.42
+
    {   "paramstring",&typeid(string*)},
    {   "permrow",&typeid(KN_<long>)},
    {   "permcol",&typeid(KN_<long>)},
@@ -526,12 +526,18 @@ bool SetDefaultSolver()
     if(verbosity>1)
 	cout << " SetDefault sparse solver to UMFPACK" << endl;
     DefSparseSolver<double>::solver  =BuildSolverUMFPack;
-    DefSparseSolver<Complex>::solver =BuildSolverUMFPack;    
+    DefSparseSolver<Complex>::solver =BuildSolverUMFPack;
+    DefSparseSolverSym<double>::solver  =BuildSolverGMRES<double>;
+    DefSparseSolverSym<Complex>::solver =BuildSolverGMRES<Complex>;
+    
 #else
     if(verbosity>1)
 	cout << " SetDefault sparse solver to GMRES (no UMFPACK)" << endl;
     DefSparseSolver<double>::solver  =BuildSolverGMRES<double>;
-    DefSparseSolver<Complex>::solver =BuildSolverGMRES<Complex>;    
+    DefSparseSolver<Complex>::solver =BuildSolverGMRES<Complex>;
+    DefSparseSolverSym<double>::solver  =BuildSolverGMRES<double>;
+    DefSparseSolverSym<Complex>::solver =BuildSolverGMRES<Complex>;
+    
 #endif
     return true;
 
@@ -552,8 +558,8 @@ void BuildCombMat(map< pair<int,int>, R> & mij,const KNM_<R> & A, int ii00=0,int
    for ( j=0;j<m;j++)
           {
            R cij=coef*A(i,j);
-           if (cnj)  cij = conj(cij); 
-           if(norm(cij) >eps0)
+           if (cnj)  cij = RNM::conj(cij); 
+           if(Fem2D::norm(cij) >eps0)
              mij[ij_mat(false,ii00,jj00,i,j)] += cij;
          
    }
@@ -1580,7 +1586,7 @@ class OneBinaryOperatorA_inv : public OneOperator { public:
           bool bb=p->EvaluableWithOutStack();
           cout << bb << " " <<  * p <<  endl;
           CompileError(" A^p, The p must be a constant == -1, sorry");}
-       long pv = GetAny<long>((*p)(0));
+       long pv = GetAny<long>((*p)(NullStack));
         if (pv !=-1)   
          { char buf[100];
            sprintf(buf," A^%ld, The pow must be  == -1, sorry",pv);
@@ -1767,7 +1773,7 @@ map< pair<int,int>, R> *Matrixfull2mapIJ_inv (KNM<R>   * const & pa,const Inv_KN
     for (long j=0;j<M;++j)
      { R aij=a(i,j);
        //cout << i << " " << j << " :: " << ii[i] << " " << jj[j] << " = " << aij << endl;
-       if(ii[i]>=0 && jj[j]>=0 && norm(aij)>1e-40) 
+       if(ii[i]>=0 && jj[j]>=0 && Fem2D::norm(aij)>1e-40) 
          A[make_pair(ii[i],jj[j])] += aij;
      }
       
@@ -1800,7 +1806,7 @@ map< pair<int,int>, R> *Matrixfull2mapIJ (KNM<R>   * const & pa,const KN_<long>
        
           R aij=a(i,j);
        //cout << i << " " << j << " :: " << ii[i] << " " << jj[j] << " = " << aij << endl;
-         if (norm(aij)>1e-40) 
+	  if (Fem2D::norm(aij)>1e-40) 
            A[make_pair(il,jl)] += aij;
        }
      }
@@ -1822,7 +1828,7 @@ AnyType Matrixfull2map (Stack , const AnyType & pp)
    for (int i=0;i<N;++i)
     for (int j=0;j<M;++j)
      { R aij=a(i,j);
-     if (norm(aij)>1e-40) 
+       if (Fem2D::norm(aij)>1e-40) 
       A[make_pair(i,j)] += aij;
      }
       
@@ -1854,8 +1860,8 @@ map< pair<int,int>, R> *Matrixoutp2mapIJ_inv (outProduct_KN_<R>   * const & pop,
    for (int i=0;i<N;++i)
     for (int j=0;j<M;++j)
      { 
-       R aij=op.a[i]*conj(op.b[j]);
-       if(ii[i]>=0 && jj[j]>=0 && norm(aij)>1e-40) 
+       R aij=op.a[i]*RNM::conj(op.b[j]);
+       if(ii[i]>=0 && jj[j]>=0 && Fem2D::norm(aij)>1e-40) 
 //       if (norm(aij)>1e-40 &) 
           A[make_pair(ii[i],jj[j])] += aij;
      }   
@@ -1977,8 +1983,8 @@ map< pair<int,int>, R> *Matrixoutp2mapIJ (outProduct_KN_<R>   * const & pop,cons
                     cerr << " Out of Bound  in (a*b')(I,J) : " << i << " " << j << " not in " << "[0,"<<N<<"[x[0," << M << "[ \n";
                     ExecError("Out of Bound Error");
                 }
-               R aij=op.a[i]*conj(op.b[j]);
-               if (norm(aij)>1e-40) 
+               R aij=op.a[i]*RNM::conj(op.b[j]);
+               if (Fem2D::norm(aij)>1e-40) 
                   A[make_pair(il,jl)] += aij;
                }
      }   
@@ -2002,8 +2008,8 @@ AnyType Matrixoutp2map (Stack , const AnyType & pp)
    for (long i=0;i<N;++i)
     for (long j=0;j<M;++j)
      { 
-      R aij=op.a[i]*conj(op.b[j]);
-      if (norm(aij)>1e-40) 
+      R aij=op.a[i]*RNM::conj(op.b[j]);
+      if (Fem2D::norm(aij)>1e-40) 
         A[make_pair(i,j)] += aij;
      } 
   delete &op;        
@@ -2094,7 +2100,7 @@ template<typename R>  BlockMatrix<R>::BlockMatrix(const basicAC_F0 & args)
 	    aType rij = c_Mij.left();
 	    if ( rij == atype<long>() &&  eij->EvaluableWithOutStack() )
 	    {
-		long contm = GetAny<long>((*eij)(0));
+		long contm = GetAny<long>((*eij)(NullStack));
 		/*  prev  version
 		if(contm !=0) 
 		CompileError(" Block matrix , Just 0 matrix");
@@ -2391,7 +2397,29 @@ template<typename R>  AnyType BlockMatrix<R>::operator()(Stack s) const
               err++;}
           }
         }
+
     if (err)    ExecError("Error Block Matrix,  size sub matrix");
+    //  gestion of zero block ????
+    
+    for (int j=0;j<M;++j)
+    {  if(verbosity>9) cout << j << " colum size" << Oj(j+1) << endl;
+        if   ( Oj(j+1) ==0) {
+            Oj(j+1)=1;
+            if( Oj(j+1) !=1)  err++;}
+    }
+    for (int i=0;i<N;++i)
+    {
+        if(verbosity>9) cout << i << " row size" << Oi(i+1) << endl;
+        if   ( Oi(i+1) ==0) {
+               Oi(i+1)=1;
+               if( Oi(i+1) !=1)  err++;}
+    }
+    if (err)    ExecError("Error Block Matrix with  0 line or  0 colomn..");
+   
+
+   
+    
+
 //  cout << "Oi = " <<  Oi << endl;
 //  cout << "Oj = " <<  Oj << endl;
 
@@ -2568,7 +2596,9 @@ TheOperators->Add("+",
  Add<Matrice_Creuse<R> *>("n",".",new OneOperator1<long,Matrice_Creuse<R> *>(get_mat_n<R>) );
  Add<Matrice_Creuse<R> *>("m",".",new OneOperator1<long,Matrice_Creuse<R> *>(get_mat_m<R>) );
  Add<Matrice_Creuse<R> *>("nbcoef",".",new OneOperator1<long,Matrice_Creuse<R> *>(get_mat_nbcoef<R>) );
- 
+ Add<Matrice_Creuse<R> *>("nnz",".",new OneOperator1<long,Matrice_Creuse<R> *>(get_mat_nbcoef<R>) );
+ Add<Matrice_Creuse<R> *>("size",".",new OneOperator1<long,Matrice_Creuse<R> *>(get_mat_nbcoef<R>) );
+    
  
  Add<Matrice_Creuse<R> *>("diag",".",new OneOperator1<TheDiagMat<R> ,Matrice_Creuse<R> *>(thediag<R>) );
  Add<Matrice_Creuse<R> *>("coef",".",new OneOperator1<TheCoefMat<R> ,Matrice_Creuse<R> *>(thecoef<R>) );
@@ -2667,6 +2697,27 @@ class PrintErrorCompileIM :  public E_F0info { public:
 
 };
 
+//  the 2 default sparse solver double and complex
+DefSparseSolver<double>::SparseMatSolver SparseMatSolver_R ; ;
+DefSparseSolver<Complex>::SparseMatSolver SparseMatSolver_C;
+DefSparseSolverSym<double>::SparseMatSolver SparseMatSolverSym_R ; ;
+DefSparseSolverSym<Complex>::SparseMatSolver SparseMatSolverSym_C;
+// the default probleme solver 
+TypeSolveMat::TSolveMat  TypeSolveMatdefaultvalue=TypeSolveMat::defaultvalue;
+
+bool SetDefault()
+{
+    if(verbosity>1)
+	cout << " SetDefault sparse to default" << endl;
+    DefSparseSolver<double>::solver =SparseMatSolver_R;
+    DefSparseSolver<Complex>::solver =SparseMatSolver_C;
+    DefSparseSolverSym<double>::solver =SparseMatSolverSym_R;
+    DefSparseSolverSym<Complex>::solver =SparseMatSolverSym_C;
+    TypeSolveMat::defaultvalue =TypeSolveMat::SparseSolver;
+    return  true;
+}
+
+
 bool SparseDefault()
 {
     return TypeSolveMat::SparseSolver== TypeSolveMat::defaultvalue;
@@ -2678,6 +2729,11 @@ bool Have_UMFPACK() { return Have_UMFPACK_;}
 void  init_lgmat() 
 
 {
+  SparseMatSolver_R= DefSparseSolver<double>::solver;
+  SparseMatSolver_C= DefSparseSolver<Complex>::solver;
+  SparseMatSolverSym_R= DefSparseSolverSym<double>::solver;
+  SparseMatSolverSym_C= DefSparseSolverSym<Complex>::solver;
+
   
   Dcl_Type<const  MatrixInterpolation<pfes>::Op *>(); 
   Dcl_Type<const  MatrixInterpolation<pfes3>::Op *>(); 
@@ -2702,6 +2758,7 @@ void  init_lgmat()
   Global.Add("defaulttoGMRES","(",new OneOperator0<bool>(SetGMRES));
   Global.Add("defaulttoCG","(",new OneOperator0<bool>(SetCG));
   Global.New("havesparsesolver",CVariable<bool>(SparseDefault));
+  Global.Add("defaultsolver","(",new OneOperator0<bool>(SetDefault));
   
   Dcl_Type< Resize<Matrice_Creuse<double> > > ();
   
@@ -2713,7 +2770,7 @@ void  init_lgmat()
  Add<Resize<Matrice_Creuse<Complex> > >("(","",new OneOperator3_<Matrice_Creuse<Complex>  *,Resize<Matrice_Creuse<Complex>  > , long, long  >(resize2));   
  
  
- Global.Add("defaultsolver","(",new OneOperator0<bool>(SetDefaultSolver));
+ //Global.Add("defaultsolver","(",new OneOperator0<bool>(SetDefaultSolver));
  
  // pour compatibiliter 
  
@@ -2746,4 +2803,4 @@ void  init_lgmat()
  init_UMFPack_solver();
 }
 
-
+int Data_Sparse_Solver_version() { return VDATASPARSESOLVER;}
