@@ -18,6 +18,6 @@ string StrVersionNumber(){
 //  buffer.precision(8);
 //  buffer<<VersionNumber();
   static char buffer[100];
-  sprintf(buffer," %9f (date Mer  3 oct 2012 15:06:21 CEST)",VersionNumber());
-  return buffer; //.str()+" (date Mer  3 oct 2012 15:06:21 CEST)" ;
+  sprintf(buffer," %9f (date Jeu 28 nov 2013 11:11:34 CET)",VersionNumber());
+  return buffer; //.str()+" (date Jeu 28 nov 2013 11:11:34 CET)" ;
 }
