@@ -40,6 +40,8 @@ using namespace std;
 #include "lgsolver.hpp"
 #include "problem.hpp"
 
+//FFCS redirection
+#include "../fflib/ffapi.hpp"
 
 #undef MPICH_SKIP_MPICXX
 #define  MPICH_SKIP_MPICXX
@@ -1253,18 +1255,9 @@ long Op_Scatterv3( KN_<R>  const  & s, KN_<R>  const  &r,  MPIrank const & root,
   
   int mpisizew;
   MPI_Comm_size(root.comm, &mpisizew); /* local */ 
- //  ffassert( sendcnts.N() == displs.N() && sendcnts.N() == mpisizew );
-  // size control 
- // ffassert( r.N() == sendcnts[mpirankv] );
-  long sumsize=0;
-  for(int ii=0; ii<sendcnts.N(); ii++){
-    sumsize += sendcnts[ii];
-  }
- // ffassert( s.N() == sumsize );
-  
-  KN<int> INTsendcnts(sendcnts.N());
-  KN<int> INTdispls(displs.N());
-  for(int ii=0; ii< sendcnts.N(); ii++){
+  KN<int> INTsendcnts(mpirankv == root.who ? sendcnts.N() : 0);
+  KN<int> INTdispls(mpirankv == root.who ? sendcnts.N() : 0);
+  for(int ii=0; ii< INTsendcnts.N(); ii++){
     INTsendcnts[ii]= sendcnts[ii];
     INTdispls[ii]= displs[ii];
   }
@@ -1434,17 +1427,9 @@ long  Op_Gatherv3(KN_<R>  const  & s, KN_<R>  const  &r,  MPIrank const & root,
   MPI_Comm_rank(root.comm, &mpirankw); 
   int mpisizew;
   MPI_Comm_size(root.comm, &mpisizew); 
- // ffassert( recvcount.N() == displs.N() && recvcount.N() == mpisizew);  fait dans mpi.. 
-  
-  if( mpirankw == root.who){
-    long sum=0;
-    for(int ii=0; ii< recvcount.N(); ii++)
-      sum+=recvcount[ii];
-   // ffassert( sum == r.N() );
-  }
-  KN<int> INTrecvcount(recvcount.N());
-  KN<int> INTdispls(displs.N());
-  for(int ii=0; ii< recvcount.N(); ii++){
+  KN<int> INTrecvcount(mpirankw == root.who ? recvcount.N() : 0);
+  KN<int> INTdispls(mpirankw == root.who ? recvcount.N() : 0);
+  for(int ii=0; ii< INTrecvcount.N(); ii++){
     INTrecvcount[ii]= recvcount[ii];
     INTdispls[ii]= displs[ii];
   }
@@ -2295,7 +2280,8 @@ public:
 // Fin add J. Morice
 void f_initparallele(int &argc, char **& argv)
 {
-  MPI_Init(&argc, &argv);
+  /// FFCS: MPI_Init() needs to be called earlier (in ffcs/src/server.cpp)
+  ffapi::mpi_init(argc,argv);
   
   int mpirank1,mpisize1;
   MPI_Comm_rank(MPI_COMM_WORLD, &mpirank1); /* local */ 
@@ -2306,8 +2292,10 @@ void f_initparallele(int &argc, char **& argv)
   if(verbosity> 2 || (mpirank ==0))
   cout << "initparallele rank " <<  mpirank << " on " << mpisize << endl;
 }
+
 double ffMPI_Wtime() {return MPI_Wtime();}
 double ffMPI_Wtick() {return MPI_Wtick();}
+
 void f_init_lgparallele()
   {
     if(verbosity && mpirank == 0) cout << "parallelempi ";
@@ -2624,7 +2612,9 @@ void f_init_lgparallele()
   }
 void f_end_parallele()
 {
-    MPI_Finalize();
+  /// FFCS: MPI_Finalize() needs to be called later than this (in
+  /// ffcs/src/server.cpp)
+  ffapi::mpi_finalize();
     if(mpirank==0 || verbosity>2) cout << "FreeFem++-mpi finalize correctly .\n" << flush ; 
     else if(verbosity>5)  cout << '.' << endl ;
 }
